==> zookeeper_3.4.9.orig.tar.xz: zookeeper-3.4.9/src/java/test/org/apache/zookeeper/ZKTestCase.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.zookeeper;

import org.junit.Assume;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.junit.Rule;
import org.junit.rules.MethodRule;
import org.junit.rules.TestWatchman;
import org.junit.runner.RunWith;
import org.junit.runners.model.FrameworkMethod;

import java.io.IOException;
import java.net.Inet6Address;
import java.net.InetAddress;

/**
 * Base class for a non-parameterized ZK test.
 *
 * Basic utilities shared by all tests. Also logging of various events during
 * the test execution (start/stop/success/failure/etc...)
 */
@RunWith(JUnit4ZKTestRunner.class)
public class ZKTestCase {
    private static final Logger LOG = LoggerFactory.getLogger(ZKTestCase.class);

    private String testName;

    protected String getTestName() {
        return testName;
    }

    @Rule
    public MethodRule watchman = new TestWatchman() {
        @Override
        public void starting(FrameworkMethod method) {
            testName = method.getName();
            LOG.info("STARTING " + testName);
        }

        @Override
        public void finished(FrameworkMethod method) {
            LOG.info("FINISHED " + testName);
        }

        @Override
        public void succeeded(FrameworkMethod method) {
            LOG.info("SUCCEEDED " + testName);
        }

        @Override
        public void failed(Throwable e, FrameworkMethod method) {
            LOG.info("FAILED " + testName, e);
        }

    };

    protected void assumeIPv6Available() {
        try {
            InetAddress address = Inet6Address.getByName("0:0:0:0:0:0:0:1");
            Assume.assumeTrue(address.isReachable(1000));
        } catch (IOException exception) {
            Assume.assumeTrue(false);
        }
    }

}

==> zookeeper_3.4.13.orig.tar.xz: zookeeper-3.4.13/src/java/test/org/apache/zookeeper/ZKTestCase.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.zookeeper;

import org.junit.Assume;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.junit.Rule;
import org.junit.rules.MethodRule;
import org.junit.rules.TestWatchman;
import org.junit.runner.RunWith;
import org.junit.runners.model.FrameworkMethod;

import java.io.IOException;
import java.net.Inet6Address;
import java.net.InetAddress;

/**
 * Base class for a non-parameterized ZK test.
 *
 * Basic utilities shared by all tests. Also logging of various events during
 * the test execution (start/stop/success/failure/etc...)
 */
@RunWith(JUnit4ZKTestRunner.class)
public class ZKTestCase {
    private static final Logger LOG = LoggerFactory.getLogger(ZKTestCase.class);

    private String testName;

    protected String getTestName() {
        return testName;
    }

    @Rule
    public MethodRule watchman = new TestWatchman() {
        @Override
        public void starting(FrameworkMethod method) {
            testName = method.getName();
            // ZOOKEEPER-2693 disables all 4lw by default.
            // Here we enable the 4lw which ZooKeeper tests depends.
            System.setProperty("zookeeper.4lw.commands.whitelist", "*");

            LOG.info("STARTING " + testName);
        }

        @Override
        public void finished(FrameworkMethod method) {
            LOG.info("FINISHED " + testName);
        }

        @Override
        public void succeeded(FrameworkMethod method) {
            LOG.info("SUCCEEDED " + testName);
        }

        @Override
        public void failed(Throwable e, FrameworkMethod method) {
            LOG.info("FAILED " + testName, e);
        }

    };

    protected void assumeIPv6Available() {
        try {
            InetAddress address = Inet6Address.getByName("0:0:0:0:0:0:0:1");
            Assume.assumeTrue(address.isReachable(1000));
        } catch (IOException exception) {
            Assume.assumeTrue(false);
        }
    }

}
